@@ -1,9 +1,10 @@
 """Interface to the OpenAI API."""
+from __future__ import annotations
+
 import hashlib
 import json
 import logging
 import os
-from typing import List, Optional, Union
 
 import openai
 
@@ -20,7 +21,7 @@ def create_completion(
     max_tokens: int,
     temperature: int = 0,
     model: str = "text-davinci-002",
-    stop: Optional[Union[str, List[str]]] = None,
+    stop: str | list[str] | None = None,
 ) -> openai.Completion:
     request_hash = hashlib.md5(
         json.dumps(
